<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the pedigree.
 *
 * @link       https://www.pedigreeonline.com
 * @since      1.0.0
 *
 * @package    Pedigree_Online
 * @subpackage Pedigree_Online/public/partials
 *
 * @input $this -- Assuming it's called within the Pedigree_Online_Public class
 * @input $data - The response object as given to us by the API
 *
 */

 $uniqid = uniqid();

?>

<div class="wrap pedigreeonline">

    <div class="pedigree-info-line">
      <a href="<?php echo $data->information->animal_link ?>" target="_blank" rel="nofollow">
      Offspring of <?php echo $data->name; ?>
      </a>
      <span class="visible-small"><br /></span> &nbsp;
      <?php echo $data->sex ?> <?php echo $data->breed ?>
    </div>

    <div class="table-responsive">
      <table class="table pedigreeonline-offspring" id="pedigreeonline-<?php echo $uniqid ?>" onclick="location.href='<?php echo $data->information->report_link ?>';">
        <thead>
          <tr>
            <th>Name</th>
            <th><?php echo $data->sex == 'Male' ? 'Dam' : 'Sire' ?></th>
          </tr>
        </thead>
        <tbody>
          <?php foreach ($data->offspring as $child) { ?>
          <tr>
          <td class="pedigree-gender-<?php echo strtolower($child->sex) ?>">

            <div>
              <?php if (false) { ?>
              <a href="<?php echo $child->url ?>" target="pedigreeonline" rel="nofollow" title="View <?php echo esc_attr($child->name) ?> pedigree on PedigreeOnline">
              <?php } ?>
                <span class="pedigree-name"><?php echo $child->name ?></span>
              <?php if (false) { ?>
              </a>
              <?php } ?>
            </div>

            <?php if ($child->dob && (($time = strtotime($child->dob))) > 0) { ?>
              <span class="pedigree-dob"><?php echo date("M. j, Y", $time) ?></span>
            <?php } ?>
              &nbsp;
            <?php if ($child->registry_number) { ?>
              <span class="pedigree-regnum">(#<?php echo $child->registry_number ?>)</span>
            <?php } ?>
              &nbsp;
            <?php if ($child->performance_titles || $child->show_titles) { ?>
              <span class="pedigree-awards">
              <?php $titles = array_filter([$child->performance_titles, $child->show_titles],'trim'); ?>
              <?php echo join(' / ', $titles); ?>
              </span>
            <?php } ?>

            </td>
            <?php $parent = $data->sex == 'Male' ? $data->mother : $data->father ?>
            <td class="pedigree-gender-<?php echo strtolower($parent->sex) ?>">

              <div>
                <?php if (false && $parent->name) { ?>
                <a href="<?php echo $parent->url ?>" target="pedigreeonline" rel="nofollow" title="View <?php echo esc_attr($parent->name) ?> pedigree on PedigreeOnline">
                <?php } ?>
                  <span class="pedigree-name"><?php echo $parent->name ?: '-' ?></span>
                <?php if (false && $parent->name) { ?>
                </a>
                <?php } ?>
              </div>

              <?php if ($parent->dob && (($time = strtotime($parent->dob))) > 0) { ?>
                <span class="pedigree-dob"><?php echo date("M. j, Y", $time) ?></span>
              <?php } ?>

            </td>
          </tr>
          <?php } ?>
          <?php if ( empty($data->offspring) ) { ?>
            <tr>
              <td><em>No offspring found for <?php echo $data->name ?></em></td>
            </tr>
          <?php } ?>
        </tbody>
      </table>
    </div>

    <div class="pedigree-footer">
      <a href="<?php echo $data->information->homepage_link ?>" title="<?php echo ucwords($data->breed ?: $data->information->animal) ?> Pedigrees" target="pedigreeonline">
      <?php echo $data->breed ?: $data->information->animal ?> Pedigrees
      </a> provided by
      PedigreeOnline.com
    </div>

</div>



